@@ -1,35 +1,14 @@
 from .config import DB_MODULES
-from .base import BaseDB, IDB
+from .base import BaseDB
+from .interface import KYDBInterface
+from .union import UnionDB
 import importlib
-from typing import Tuple
-
-
-class UnionDB:
-    def __init__(self, dbs: Tuple[BaseDB]):
-        self.dbs = dbs
-
-    def exists(self, key: str):
-        return any(db.exists(key) for db in self.dbs)
-
-    def __getitem__(self, key: str):
-        for db in self.dbs:
-            try:
-                return db[key]
-            except KeyError:
-                pass
-
-        raise KeyError(key)
-
-    def __setitem__(self, key, value):
-        print(f'setting {key} to {value}')
-        print(f'db = {self.dbs[0]}')
-        self.dbs[0][key] = value
 
 
 _db_cache = {}
 
 
-def connect(url: str) -> IDB:
+def connect(url: str) -> KYDBInterface:
     dbs = [_connect(x) for x in url.split(';')]
     if len(dbs) == 1:
         return dbs[0]
